==> cutemaze_1.2.0.orig.tar.gz: cutemaze-1.2.0/translations/cutemaze_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Lo sentimos</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>No se pudo cargar la partida anterior. Se iniciará una nueva.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 transcurridos</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 pasos dados</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>Quedan %1 de %2 objetivos</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Éxito</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>En pausa</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Mayús</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Opción</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleccione el idioma de la aplicación:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Reinicie la aplicación para que el cambio de idioma surta efecto.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Partida nueva</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Hunt-and-Kill</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Vuelta atrás recursiva</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Pila</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Pila 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Pila 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Pila 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Pila 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritmo:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Objetivos:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Hunt-and-Kill</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Vuelta atrás recursiva</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Pila</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Pila 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Pila 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Pila 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Pila 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>Puntuaciones de CuteMaze</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Puntuación</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tiempo</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Pasos</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritmo</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>¡Felicidades!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>Su puntuación está entre las diez mejores.
Escriba su nombre:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Partida</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Mostrar dónde ha estado</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Mostrar la cantidad de pasos dados</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Mostrar el tiempo transcurrido</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Movimiento suave</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controles</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Mover hacia arriba:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Mover hacia abajo:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Mover hacia la izquierda:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Mover hacia la derecha:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Conmutar la marca:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Temas:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Seleccione el archivo de tema</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Lo sentimos</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>No se pudo crear la carpeta de datos.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>No se pudo copiar el archivo de tema.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>¿Quiere eliminar el tema seleccionado?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>No se pudo eliminar el tema seleccionado.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Partida</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausar</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>P&amp;ista</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>P&amp;untuaciones altas</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Acercar</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Al&amp;ejar</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>I&amp;dioma de la aplicación…</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferencias…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ay&amp;uda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Un juego de laberinto en vista superior</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2007–%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publicado bajo la licencia &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Los iconos provienen del tema &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Utilizado bajo la licencia &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> cutemaze_1.2.4.orig.tar.gz: cutemaze-1.2.4/translations/cutemaze_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Lo sentimos</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>No se pudo cargar la partida anterior. Se iniciará una nueva.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 transcurridos</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 pasos dados</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>Quedan %1 de %2 objetivos</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Éxito</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>En pausa</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Mayús</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Opción</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleccione el idioma de la aplicación:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Reinicie la aplicación para que el cambio de idioma surta efecto.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Partida nueva</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Hunt-and-Kill</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Vuelta atrás recursiva</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Pila</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Pila 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Pila 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Pila 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Pila 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritmo:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Objetivos:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Hunt-and-Kill</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Vuelta atrás recursiva</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Pila</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Pila 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Pila 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Pila 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Pila 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>Puntuaciones de CuteMaze</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Puntuación</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tiempo</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Pasos</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritmo</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>¡Felicidades!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>Su puntuación está entre las diez mejores.
Escriba su nombre:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Partida</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Mostrar dónde ha estado</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Mostrar la cantidad de pasos dados</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Mostrar el tiempo transcurrido</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Movimiento suave</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controles</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Mover hacia arriba:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Mover hacia abajo:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Mover hacia la izquierda:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Mover hacia la derecha:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Conmutar la marca:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Temas:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Seleccione el archivo de tema</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Lo sentimos</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>No se pudo crear la carpeta de datos.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>No se pudo copiar el archivo de tema.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>¿Quiere eliminar el tema seleccionado?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>No se pudo eliminar el tema seleccionado.</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Partida</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausar</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>P&amp;ista</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>P&amp;untuaciones altas</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Acercar</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Al&amp;ejar</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>I&amp;dioma de la aplicación…</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferencias…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ay&amp;uda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Un juego de laberinto en vista superior</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2007–%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publicado bajo la licencia &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Los iconos provienen del tema &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Utilizado bajo la licencia &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>
